@@ -122,6 +122,8 @@ namespace DisplayPort
         ConnectorType     connectorType;
         Address           address;
         GUID              guid;
+        GUID              guid2;
+        bool              bVirtualPeerDevice;
         NvU8              peerDevice;
         NvU8              dpcdRevisionMajor;
         NvU8              dpcdRevisionMinor;
@@ -171,6 +173,8 @@ namespace DisplayPort
         bool bIsFakedMuxDevice;
         bool bIsPreviouslyFakedMuxDevice;
         bool bisMarkedForDeletion;
+        bool bIgnoreMsaCap;
+        bool bIgnoreMsaCapCached;
 
         //
         // Device doing the DSC decompression for this device. This could be device itself
@@ -192,6 +196,7 @@ namespace DisplayPort
 
         TriState bSdpExtCapable;
         bool bMSAOverMSTCapable;
+        bool bDscPassThroughColorFormatWar;
 
         DeviceImpl(DPCDHAL * hal, ConnectorImpl * connector, DeviceImpl * parent);
         ~DeviceImpl();
@@ -347,18 +352,37 @@ namespace DisplayPort
             return true;
         }
 
-        bool getIgnoreMSACap()
+        bool getIgnoreMSACap();
+
+        AuxRetry::status setIgnoreMSAEnable(bool msaTimingParamIgnoreEn);
+
+        bool isVirtualPeerDevice()
         {
-            return hal->getMsaTimingparIgnored();
+            return bVirtualPeerDevice;
         }
 
-        AuxRetry::status setIgnoreMSAEnable(bool msaTimingParamIgnoreEn)
+        bool isBranchDevice()
         {
-            return hal->setIgnoreMSATimingParamters(msaTimingParamIgnoreEn);
+            return !isVideoSink() && !isAudioSink();
         }
 
+        bool  isAtLeastVersion(unsigned major, unsigned minor)
+        {
+            if (dpcdRevisionMajor > major)
+                return true;
+
+            if (dpcdRevisionMajor < major)
+                return false;
+
+            return dpcdRevisionMinor >= minor;
+        }
+
+        virtual void queryGUID2();
+
         virtual bool getSDPExtnForColorimetrySupported();
 
+        virtual bool getPanelFwRevision(NvU16 *revision);
+
         virtual bool isPowerSuspended();
 
         virtual void setPanelPowerParams(bool bSinkPowerStateD0, bool bPanelPowerStateOn);
@@ -417,6 +441,7 @@ namespace DisplayPort
         bool isPanelReplaySupported(void);
         void getPanelReplayCaps(void);
         bool setPanelReplayConfig(panelReplayConfig prcfg);
+        bool getPanelReplayStatus(PanelReplayStatus *pPrStatus);
 
         NvBool getDSCSupport();
         bool getFECSupport();
@@ -429,6 +454,7 @@ namespace DisplayPort
         bool parseDscCaps(const NvU8 *buffer, NvU32 bufferSize);
         bool parseBranchSpecificDscCaps(const NvU8 *buffer, NvU32 bufferSize);
         bool setDscEnable(bool enable);
+        bool setDscEnableDPToHDMIPCON(bool bDscEnable, bool bEnablePassThroughForPCON);
         bool getDscEnable(bool *pEnable);
         unsigned getDscVersionMajor();
         unsigned getDscVersionMinor();
@@ -447,6 +473,7 @@ namespace DisplayPort
         unsigned getDscPeakThroughputModel();
         unsigned getDscMaxSliceWidth();
         unsigned getDscDecoderColorDepthSupportMask();
+        void setDscDecompressionDevice(bool bDscCapBasedOnParent);
     };
     class DeviceHDCPDetection : public Object, MessageManager::Message::MessageEventSink, Timer::TimerCallback
     {
